﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Microsoft.PointOfService;

namespace PaylinkUPOSDemo
{
    // ------------------------------------------------------------------
    // We have Paylink-specific "DirectIO" commands.
    // As such, they are not accessible through the
    // standard "CashChanger" interface and must be
    // explicitly defined here.
    //
    // At time of writing, these are limited to a
    // single command to drive a pattern of LEDs.
    // ------------------------------------------------------------------

    public enum PaylinkIOCommands
    {
        PaylinkDriveLEDs = 0
    }  ;

    // ------------------------------------------------------------------
    // We also have definitions of the possible responses
    // ------------------------------------------------------------------

    public enum PaylinkIOResponses
    {
        PaylinkOK = 0,
        PaylinkUnrecognisedCommand
    } ;

    // ------------------------------------------------------------------
    // And we have a number of definitions of direct I/O events
    // ------------------------------------------------------------------

    public enum PaylinkIOEvents
    {
        PaylinkSwitchChangeEvent = 0
    } ;

    public partial class PaylinkUPOSDemo : Form
    {
        PosExplorer myExplorer;
        CashChanger myChanger;        // The Paylink Cash Changer

        CashUnits myCashUnits;        // Cash units supported by the changer
        CashUnits myDepositUnits;     // Cash units accepted  by the changer
        CashUnits myDispenseUnits;    // Cash units dispensed by the changer

        public PaylinkUPOSDemo()
        {
            InitializeComponent();
        }

        private void PaylinkUPOSDemo_Load(object sender, EventArgs e)
        {
            Tracef.format("App: Form Loading\n");

            myExplorer = new PosExplorer(this);

            // We need events for the adding and removing of the
            // Plug and Play Cash Changer from the system

            myExplorer.DeviceAddedEvent   += new DeviceChangedEventHandler(myExplorer_DeviceAddedEvent);
            myExplorer.DeviceRemovedEvent += new DeviceChangedEventHandler(myExplorer_DeviceRemovedEvent);

            DeviceInfo ChangerDevice = myExplorer.GetDevice("CashChanger");

            if (ChangerDevice == null)
            {
                Tracef.simple("App: Changer Not Found\n");

                ToolStripStatusLabel.Text = "Changer Not Found";
            }
            else
            {
                myChanger = (CashChanger)myExplorer.CreateInstance(ChangerDevice);

                Tracef.simple("App: Changer Found\n");

                myChangerSetupEvents();

                myChanger.Open();
                myChanger.Claim(5000);
                myChanger.DeviceEnabled = true;

                ToolStripStatusLabel.Text = "Changer Ready";
            }

            // Now we need to populate the various form controls

            for (int i = 0; i <= 10; i++)
            {
                // Populate the Coin Dispense Combos

                CoinDispenseCombo0.Items.Add(i);
                CoinDispenseCombo1.Items.Add(i);
                CoinDispenseCombo2.Items.Add(i);
                CoinDispenseCombo3.Items.Add(i);
                CoinDispenseCombo4.Items.Add(i);
                CoinDispenseCombo5.Items.Add(i);
                CoinDispenseCombo6.Items.Add(i);
                CoinDispenseCombo7.Items.Add(i);
                CoinDispenseCombo8.Items.Add(i);
                CoinDispenseCombo9.Items.Add(i);
                CoinDispenseCombo10.Items.Add(i);
                CoinDispenseCombo11.Items.Add(i);
                CoinDispenseCombo12.Items.Add(i);
                CoinDispenseCombo13.Items.Add(i);
                CoinDispenseCombo14.Items.Add(i);
                CoinDispenseCombo15.Items.Add(i);

                // Populate the Note Dispense Combos
                
                NoteDispenseCombo0.Items.Add(i);
                NoteDispenseCombo1.Items.Add(i);
                NoteDispenseCombo2.Items.Add(i);
                NoteDispenseCombo3.Items.Add(i);
                NoteDispenseCombo4.Items.Add(i);
                NoteDispenseCombo5.Items.Add(i);
                NoteDispenseCombo6.Items.Add(i);
                NoteDispenseCombo7.Items.Add(i);
                NoteDispenseCombo8.Items.Add(i);
                NoteDispenseCombo9.Items.Add(i);
                NoteDispenseCombo10.Items.Add(i);
                NoteDispenseCombo11.Items.Add(i);
                NoteDispenseCombo12.Items.Add(i);
                NoteDispenseCombo13.Items.Add(i);
                NoteDispenseCombo14.Items.Add(i);
                NoteDispenseCombo15.Items.Add(i);
            }

            // And set the initial index values

            CoinDispenseCombo0.SelectedIndex = 0;
            CoinDispenseCombo1.SelectedIndex = 0;
            CoinDispenseCombo2.SelectedIndex = 0;
            CoinDispenseCombo3.SelectedIndex = 0;
            CoinDispenseCombo4.SelectedIndex = 0;
            CoinDispenseCombo5.SelectedIndex = 0;
            CoinDispenseCombo6.SelectedIndex = 0;
            CoinDispenseCombo7.SelectedIndex = 0;
            CoinDispenseCombo8.SelectedIndex = 0;
            CoinDispenseCombo9.SelectedIndex = 0;
            CoinDispenseCombo10.SelectedIndex = 0;
            CoinDispenseCombo11.SelectedIndex = 0;
            CoinDispenseCombo12.SelectedIndex = 0;
            CoinDispenseCombo13.SelectedIndex = 0;
            CoinDispenseCombo14.SelectedIndex = 0;
            CoinDispenseCombo15.SelectedIndex = 0;

            NoteDispenseCombo0.SelectedIndex = 0;
            NoteDispenseCombo1.SelectedIndex = 0;
            NoteDispenseCombo2.SelectedIndex = 0;
            NoteDispenseCombo3.SelectedIndex = 0;
            NoteDispenseCombo4.SelectedIndex = 0;
            NoteDispenseCombo5.SelectedIndex = 0;
            NoteDispenseCombo6.SelectedIndex = 0;
            NoteDispenseCombo7.SelectedIndex = 0;
            NoteDispenseCombo8.SelectedIndex = 0;
            NoteDispenseCombo9.SelectedIndex = 0;
            NoteDispenseCombo10.SelectedIndex = 0;
            NoteDispenseCombo11.SelectedIndex = 0;
            NoteDispenseCombo12.SelectedIndex = 0;
            NoteDispenseCombo13.SelectedIndex = 0;
            NoteDispenseCombo14.SelectedIndex = 0;
            NoteDispenseCombo15.SelectedIndex = 0;
        }

        private void PaylinkUPOSDemo_FormClosing(object sender, FormClosingEventArgs e)
        {
            Tracef.simple("App: Form Closing\n");

            myChanger.Close();
        }

        void myExplorer_DeviceAddedEvent(object sender, DeviceChangedEventArgs e)
        {
            Tracef.simple("App: Device Added Event Fired\n");
        }

        void myExplorer_DeviceRemovedEvent(object sender, DeviceChangedEventArgs e)
        {
            Tracef.simple("App: Device Removed Event Fired\n");
        }

        #region Event Registration

        private void myChangerSetupEvents()
        {
            Tracef.simple("App: Adding Status Update Event\n");

            myChanger.StatusUpdateEvent +=
                new StatusUpdateEventHandler(myChangerStatusUpdateEvent);

            Tracef.simple("App: Adding Direct IO Event\n");

            myChanger.DirectIOEvent +=
                new DirectIOEventHandler(myChangerDirectIOEvent);

            Tracef.simple("App: Adding Data Event\n");

            myChanger.DataEvent +=
                new DataEventHandler(myChangerDataEvent);
        }

        #endregion Event Registration

        #region SO Event Handlers

        void myChangerStatusUpdateEvent(object sender, StatusUpdateEventArgs e)
        {
            Tracef.simple("App: Status Update Event Fired\n");
        }

        void myChangerDirectIOEvent(object sender, DirectIOEventArgs e)
        {
            Tracef.simple("App: Direct IO Event Fired\n");

            if (e.EventNumber == (int) PaylinkIOEvents.PaylinkSwitchChangeEvent)
            {
                // Then we have a "switch change" event

                UInt16 NewSwitchPattern = (UInt16)e.Data;

                SwitchCheck0.Checked = (NewSwitchPattern & 0x0001) != 0;
                SwitchCheck1.Checked = (NewSwitchPattern & 0x0002) != 0;
                SwitchCheck2.Checked = (NewSwitchPattern & 0x0004) != 0;
                SwitchCheck3.Checked = (NewSwitchPattern & 0x0008) != 0;

                SwitchCheck4.Checked = (NewSwitchPattern & 0x0010) != 0;
                SwitchCheck5.Checked = (NewSwitchPattern & 0x0020) != 0;
                SwitchCheck6.Checked = (NewSwitchPattern & 0x0040) != 0;
                SwitchCheck7.Checked = (NewSwitchPattern & 0x0080) != 0;

                SwitchCheck8.Checked = (NewSwitchPattern & 0x0100) != 0;
                SwitchCheck9.Checked = (NewSwitchPattern & 0x0200) != 0;
                SwitchCheck10.Checked = (NewSwitchPattern & 0x0400) != 0;
                SwitchCheck11.Checked = (NewSwitchPattern & 0x0800) != 0;

                SwitchCheck12.Checked = (NewSwitchPattern & 0x1000) != 0;
                SwitchCheck13.Checked = (NewSwitchPattern & 0x2000) != 0;
                SwitchCheck14.Checked = (NewSwitchPattern & 0x4000) != 0;
                SwitchCheck15.Checked = (NewSwitchPattern & 0x8000) != 0;
            }
        }

        void myChangerDataEvent(object sender, DataEventArgs e)
        {
            Tracef.simple("App: Data Event Fired!!\n");

            UpdateDepositedCashTotals();

            myChanger.DataEventEnabled = true;
        }

        #endregion SO Event Handlers

        #region Form Event Handlers

        private void CurrencyButton_Click(object sender, EventArgs e)
        {
            string TempCurrency = myChanger.CurrencyCode;

            CurrencyTextBox.Text = TempCurrency;
        }

        // ------------------------------------------------------------------
        // Clicking on this button causes Paylink to return a
        // structure with ALL the currencies that are supported.
        // ------------------------------------------------------------------

        private void CurrenciesButton_Click(object sender, EventArgs e)
        {
            string[] CurrencyArray = myChanger.CurrencyCodeList;

            int SupportedCurrencies;

            SupportedCurrencies = CurrencyArray.Length;

            CurrenciesComboBox.Items.Clear();

            for (int i = 0; i < SupportedCurrencies; i++)
            {
                CurrenciesComboBox.Items.Add(CurrencyArray[i]);
            }

            CurrenciesComboBox.SelectedIndex = 0;
            
            if (SupportedCurrencies > 1)
            {
                SetCurrencyButton.Enabled = true;
            }
            else
            {
                SetCurrencyButton.Enabled = false;
            }
        }

        // ------------------------------------------------------------------
        // Clicking on this button causes a currency from
        // the "currencies" combo box to be selected as the
        // operational currency for the Paylink system.
        // ------------------------------------------------------------------

        private void SetCurrencyButton_Click(object sender, EventArgs e)
        {
            string NewCurrency = CurrenciesComboBox.SelectedItem.ToString();

            myChanger.CurrencyCode = NewCurrency;

            Tracef.simple("App New " + NewCurrency + "\n");
        }

        // ------------------------------------------------------------------
        // Clicking on this button causes a request for the payout
        // currency list to be retrieved from Paylink.
        //
        // This is a list of all the note and coin values that are
        // HANDLED by the cash changer.
        // ------------------------------------------------------------------

        private void GetCurrencyListButton_Click(object sender, EventArgs e)
        {
            myCashUnits = myChanger.CurrencyCashList;

            CoinsListBox.Items.Clear();
            NotesListBox.Items.Clear();

            for (int i = 0; i < myCashUnits.Coins.Length; i++)
            {
                if (myCashUnits.Coins[i] > 0)
                {
                    CoinsListBox.Items.Add(myCashUnits.Coins[i].ToString());
                }
            }

            for (int i = 0; i < myCashUnits.Bills.Length; i++)
            {
                if (myCashUnits.Bills[i] > 0)
                {
                    NotesListBox.Items.Add(myCashUnits.Bills[i].ToString());
                }
            }
        }

        // ------------------------------------------------------------------
        // Clicking on this button causes a request for the payout
        // currency list to be retrieved from Paylink.
        //
        // This is a list of all the note and coin values that are
        // ACCEPTED by the cash changer.
        // ------------------------------------------------------------------

        private void GetDepositCurrenciesButton_Click(object sender, EventArgs e)
        {
            myDepositUnits = myChanger.DepositCashList;

            PopulateAcceptBillCurrencyValues();
            PopulateAcceptCoinCurrencyValues();

            // Now we can allow acceptance, as we
            // know what we are likely to get!!

            BeginDepositButton.Enabled = true;
        }

        // ------------------------------------------------------------------
        // Clicking on this button causes a request for the payout
        // currency list to be retrieved from Paylink.
        //
        // This is a list of all the note and coin values that are
        // DISPENSED by the cash changer.
        // ------------------------------------------------------------------

        private void GetDispenseCurrenciesButton_Click(object sender, EventArgs e)
        {
            myDispenseUnits = myChanger.ExitCashList;

            PopulateDispenseBillCurrencyValues();
            PopulateDispenseCoinCurrencyValues();

            DispenseNotesAndCoinsButton.Enabled = true;
        }

        // ------------------------------------------------------------------
        // Clicking on the "Dispense Cash Value" button causes
        // a request for payment based on cash VALUE to be sent
        // to Paylink.
        //
        // In this case, Paylink is  free to choose how the
        // payout should be fulfilled.
        // ------------------------------------------------------------------

        private void DispenseButton_Click(object sender, EventArgs e)
        {
            int DispenseAmount = System.Convert.ToInt32(DispenseTextBox.Text);

            myChanger.DispenseChange(DispenseAmount);
        }

        // ------------------------------------------------------------------
        // Clicking on the "Dispense Notes and Coins" button causes
        // a request for payment to be sent to Paylink, where the
        // counts of individual notes and coins are specified.
        //
        // Although the Paylink Service Object naturally supports
        // this feature, the preferred payment method is via VALUE.
        // ------------------------------------------------------------------

        private void DispenseNotesAndCoinsButton_Click(object sender, EventArgs e)
        {
            // First we get a count of the total number
            // of bills and coins that can be dispensed

            int DispenseUnitCount = myDispenseUnits.Bills.Length + myDispenseUnits.Coins.Length;

            CashCount[] CashToPay = new CashCount[DispenseUnitCount];

            for (int i = 0; i < myDispenseUnits.Coins.Length; i++)
            {
                int CoinPayCount = GetCoinPayCount(i);

                CashToPay[i] =
                    new CashCount(Microsoft.PointOfService.CashCountType.Coin, myDispenseUnits.Coins[i], CoinPayCount);
            }

            for (int i = 0; i < myDispenseUnits.Bills.Length; i++)
            {
                int NotePayCount = GetNotePayCount(i);

                CashToPay[i + myDispenseUnits.Coins.Length] =
                    new CashCount(Microsoft.PointOfService.CashCountType.Bill, myDispenseUnits.Bills[i], NotePayCount);
            }

            myChanger.DispenseCash(CashToPay);
        }

        // ------------------------------------------------------------------
        // Clicking on the "Begin Deposit" button causes
        // a cash acceptance operation to commence.
        //
        // This will have the effect of zeroising the
        // various counters and enabling all acceptor
        // devices.
        // ------------------------------------------------------------------

        private void BeginDepositButton_Click(object sender, EventArgs e)
        {
            // Should the event enabling happen within BeginDeposit?

            myChanger.DataEventEnabled = true;

            myChanger.BeginDeposit();

            // Now we read the initial cash counts and
            // update the "acceptance" fileds on the form.

            UpdateDepositedCashTotals();

            BeginDepositButton.Enabled = false;
            PauseDepositButton.Enabled = true;
            FixDepositButton.Enabled   = true;
        }

        // ------------------------------------------------------------------
        // Clicking on the "Pause Deposit" button causes the
        // acceptance of cash to be paused (inhibited). 
        //
        //  Clicking on the "Resume Deposit" button causes the
        // acceptance of cash to be resumed (enabled).
        // 
        // Prior to calling Pause or Resume Deposit, Begin 
        // Deposit must be called or an exception will be thrown.
        // ------------------------------------------------------------------

        private void PauseDepositButton_Click(object sender, EventArgs e)
        {
            myChanger.PauseDeposit(Microsoft.PointOfService.CashDepositPause.Pause);

            PauseDepositButton.Enabled  = false;
            FixDepositButton.Enabled    = false;
            ResumeDepositButton.Enabled = true;
        }

        private void ResumeDepositButton_Click(object sender, EventArgs e)
        {
            myChanger.PauseDeposit(Microsoft.PointOfService.CashDepositPause.Restart);

            PauseDepositButton.Enabled  = true;
            FixDepositButton.Enabled    = true;
            ResumeDepositButton.Enabled = false;
        }

        // ------------------------------------------------------------------
        // Clicking on the "Fix Deposit" button causes the
        // cash changer service object to update all property
        // values to be updated to reflect the  current values
        // in the cash changer.
        //
        // As this is called prior to ending the deposit operation,
        // it is assumed that cash acceptance will be inhibited
        // following this call.
        // ------------------------------------------------------------------

        private void FixDepositButton_Click(object sender, EventArgs e)
        {
            myChanger.FixDeposit();

            PauseDepositButton.Enabled  = false;
            ResumeDepositButton.Enabled = false;
            FixDepositButton.Enabled    = false;
            EndDepositButton.Enabled    = true;
        }

        // ------------------------------------------------------------------
        // Clicking on "End Deposit" button causes the "End 
        // Deposit" method of the cash changer service object
        // to ne invoked.
        // 
        // Prior to calling End Deposit, Fix Deposit must be called
        // or an exception will be thrown.
        // ------------------------------------------------------------------

        private void EndDepositButton_Click(object sender, EventArgs e)
        {
            myChanger.EndDeposit(Microsoft.PointOfService.CashDepositAction.NoChange);

            BeginDepositButton.Enabled = true;
            EndDepositButton.Enabled   = false;
        }

        // ------------------------------------------------------------------
        // Clicking on ANY of the LED check boxes causes a new
        // set of LED states to be sent to the changer
        // ------------------------------------------------------------------

        private void LEDCheck_CheckedChanged(object sender, EventArgs e)
        {
            object TempObject = new object();

            UInt16 LEDPattern = 0x0000;
            
            if (LEDCheck0.Checked == true)
            {
                LEDPattern |= 0x0001;
            }

            if (LEDCheck1.Checked == true)
            {
                LEDPattern |= 0x0002;
            }

            if (LEDCheck2.Checked == true)
            {
                LEDPattern |= 0x0004;
            }

            if (LEDCheck3.Checked == true)
            {
                LEDPattern |= 0x0008;
            }

            if (LEDCheck4.Checked == true)
            {
                LEDPattern |= 0x0010;
            }

            if (LEDCheck5.Checked == true)
            {
                LEDPattern |= 0x0020;
            }

            if (LEDCheck6.Checked == true)
            {
                LEDPattern |= 0x0040;
            }

            if (LEDCheck7.Checked == true)
            {
                LEDPattern |= 0x0080;
            }

            if (LEDCheck8.Checked == true)
            {
                LEDPattern |= 0x0100;
            }

            if (LEDCheck9.Checked == true)
            {
                LEDPattern |= 0x0200;
            }

            if (LEDCheck10.Checked == true)
            {
                LEDPattern |= 0x0400;
            }

            if (LEDCheck11.Checked == true)
            {
                LEDPattern |= 0x0800;
            }

            if (LEDCheck12.Checked == true)
            {
                LEDPattern |= 0x1000;
            }

            if (LEDCheck13.Checked == true)
            {
                LEDPattern |= 0x2000;
            }

            if (LEDCheck14.Checked == true)
            {
                LEDPattern |= 0x4000;
            }

            if (LEDCheck15.Checked == true)
            {
                LEDPattern |= 0x8000;
            }

            DirectIOData IOResponse;

            IOResponse = myChanger.DirectIO((int) PaylinkIOCommands.PaylinkDriveLEDs, LEDPattern, TempObject);

            if (IOResponse.Data == (int) PaylinkIOResponses.PaylinkOK)
            {
                // Success! The command was accepted
            }
            else
            {
                Tracef.simple("App: Set LEDs returned " + IOResponse.Data + "\n");
            }
        }

        #endregion Form Event Handlers

        #region Support Functions

        private void PopulateAcceptCoinCurrencyValues()
        {
            int CoinCounter = myDepositUnits.Coins.Length;

            // Coin 0?

            if (CoinCounter > 0)
            {
                CoinDepositBox0.Visible = true;
                CoinLabel0.Visible = true;
                CoinLabel0.Text = myDepositUnits.Coins[0].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox0.Visible = false;
                CoinLabel0.Visible = false;
            }

            // Coin 1?

            if (CoinCounter > 0)
            {
                CoinDepositBox1.Visible = true;
                CoinLabel1.Visible = true;
                CoinLabel1.Text = myDepositUnits.Coins[1].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox1.Visible = false;
                CoinLabel1.Visible = false;
            }

            // Coin 2?

            if (CoinCounter > 0)
            {
                CoinDepositBox2.Visible = true;
                CoinLabel2.Visible = true;
                CoinLabel2.Text = myDepositUnits.Coins[2].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox2.Visible = false;
                CoinLabel2.Visible = false;
            }

            // Coin 3?

            if (CoinCounter > 0)
            {
                CoinDepositBox3.Visible = true;
                CoinLabel3.Visible = true;
                CoinLabel3.Text = myDepositUnits.Coins[3].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox3.Visible = false;
                CoinLabel3.Visible = false;
            }

            // Coin 4?

            if (CoinCounter > 0)
            {
                CoinDepositBox4.Visible = true;
                CoinLabel4.Visible = true;
                CoinLabel4.Text = myDepositUnits.Coins[4].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox4.Visible = false;
                CoinLabel4.Visible = false;
            }

            // Coin 5?

            if (CoinCounter > 0)
            {
                CoinDepositBox5.Visible = true;
                CoinLabel5.Visible = true;
                CoinLabel5.Text = myDepositUnits.Coins[5].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox5.Visible = false;
                CoinLabel5.Visible = false;
            }

            // Coin 6?

            if (CoinCounter > 0)
            {
                CoinDepositBox6.Visible = true;
                CoinLabel6.Visible = true;
                CoinLabel6.Text = myDepositUnits.Coins[6].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox6.Visible = false;
                CoinLabel6.Visible = false;
            }

            // Coin 7?

            if (CoinCounter > 0)
            {
                CoinDepositBox7.Visible = true;
                CoinLabel7.Visible = true;
                CoinLabel7.Text = myDepositUnits.Coins[7].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox7.Visible = false;
                CoinLabel7.Visible = false;
            }

            // Coin 8?

            if (CoinCounter > 0)
            {
                CoinDepositBox8.Visible = true;
                CoinLabel8.Visible = true;
                CoinLabel8.Text = myDepositUnits.Coins[8].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox8.Visible = false;
                CoinLabel8.Visible = false;
            }

            // Coin 9?

            if (CoinCounter > 0)
            {
                CoinDepositBox9.Visible = true;
                CoinLabel9.Visible = true;
                CoinLabel9.Text = myDepositUnits.Coins[9].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox9.Visible = false;
                CoinLabel9.Visible = false;
            }

            // Coin 10?

            if (CoinCounter > 0)
            {
                CoinDepositBox10.Visible = true;
                CoinLabel10.Visible = true;
                CoinLabel10.Text = myDepositUnits.Coins[10].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox10.Visible = false;
                CoinLabel10.Visible = false;
            }

            // Coin 11?

            if (CoinCounter > 0)
            {
                CoinDepositBox11.Visible = true;
                CoinLabel11.Visible = true;
                CoinLabel11.Text = myDepositUnits.Coins[11].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox11.Visible = false;
                CoinLabel11.Visible = false;
            }

            // Coin 12?

            if (CoinCounter > 0)
            {
                CoinDepositBox12.Visible = true;
                CoinLabel12.Visible = true;
                CoinLabel12.Text = myDepositUnits.Coins[12].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox12.Visible = false;
                CoinLabel12.Visible = false;
            }

            // Coin 13?

            if (CoinCounter > 0)
            {
                CoinDepositBox13.Visible = true;
                CoinLabel13.Visible = true;
                CoinLabel13.Text = myDepositUnits.Coins[13].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox13.Visible = false;
                CoinLabel13.Visible = false;
            }

            // Coin 14?

            if (CoinCounter > 0)
            {
                CoinDepositBox14.Visible = true;
                CoinLabel14.Visible = true;
                CoinLabel14.Text = myDepositUnits.Coins[14].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox14.Visible = false;
                CoinLabel14.Visible = false;
            }

            // Coin 15?

            if (CoinCounter > 0)
            {
                CoinDepositBox15.Visible = true;
                CoinLabel15.Visible = true;
                CoinLabel15.Text = myDepositUnits.Coins[15].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDepositBox15.Visible = false;
                CoinLabel15.Visible = false;
            }
        }

        private void PopulateAcceptBillCurrencyValues()
        {
            int BillCounter = myDepositUnits.Bills.Length;

            // Bill 0?

            if (BillCounter > 0)
            {
                NoteDepositBox0.Visible = true;
                NoteLabel0.Visible = true;
                NoteLabel0.Text = myDepositUnits.Bills[0].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox0.Visible = false;
                NoteLabel0.Visible = false;
            }

            // Bill 1?

            if (BillCounter > 0)
            {
                NoteDepositBox1.Visible = true;
                NoteLabel1.Visible = true;
                NoteLabel1.Text = myDepositUnits.Bills[1].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox1.Visible = false;
                NoteLabel1.Visible = false;
            }

            // Bill 2?

            if (BillCounter > 0)
            {
                NoteDepositBox2.Visible = true;
                NoteLabel2.Visible = true;
                NoteLabel2.Text = myDepositUnits.Bills[2].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox2.Visible = false;
                NoteLabel2.Visible = false;
            }

            // Bill 3?

            if (BillCounter > 0)
            {
                NoteDepositBox3.Visible = true;
                NoteLabel3.Visible = true;
                NoteLabel3.Text = myDepositUnits.Bills[3].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox3.Visible = false;
                NoteLabel3.Visible = false;
            }

            // Bill 4?

            if (BillCounter > 0)
            {
                NoteDepositBox4.Visible = true;
                NoteLabel4.Visible = true;
                NoteLabel4.Text = myDepositUnits.Bills[4].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox4.Visible = false;
                NoteLabel4.Visible = false;
            }

            // Bill 5?

            if (BillCounter > 0)
            {
                NoteDepositBox5.Visible = true;
                NoteLabel5.Visible = true;
                NoteLabel5.Text = myDepositUnits.Bills[5].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox5.Visible = false;
                NoteLabel5.Visible = false;
            }

            // Bill 6?

            if (BillCounter > 0)
            {
                NoteDepositBox6.Visible = true;
                NoteLabel6.Visible = true;
                NoteLabel6.Text = myDepositUnits.Bills[6].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox6.Visible = false;
                NoteLabel6.Visible = false;
            }

            // Bill 7?

            if (BillCounter > 0)
            {
                NoteDepositBox7.Visible = true;
                NoteLabel7.Visible = true;
                NoteLabel7.Text = myDepositUnits.Bills[7].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox7.Visible = false;
                NoteLabel7.Visible = false;
            }

            // Bill 8?

            if (BillCounter > 0)
            {
                NoteDepositBox8.Visible = true;
                NoteLabel8.Visible = true;
                NoteLabel8.Text = myDepositUnits.Bills[8].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox8.Visible = false;
                NoteLabel8.Visible = false;
            }

            // Bill 9?

            if (BillCounter > 0)
            {
                NoteDepositBox9.Visible = true;
                NoteLabel9.Visible = true;
                NoteLabel9.Text = myDepositUnits.Bills[9].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox9.Visible = false;
                NoteLabel9.Visible = false;
            }

            // Bill 10?

            if (BillCounter > 0)
            {
                NoteDepositBox10.Visible = true;
                NoteLabel10.Visible = true;
                NoteLabel10.Text = myDepositUnits.Bills[10].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox10.Visible = false;
                NoteLabel10.Visible = false;
            }

            // Bill 11?

            if (BillCounter > 0)
            {
                NoteDepositBox11.Visible = true;
                NoteLabel11.Visible = true;
                NoteLabel11.Text = myDepositUnits.Bills[11].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox11.Visible = false;
                NoteLabel11.Visible = false;
            }

            // Bill 12?

            if (BillCounter > 0)
            {
                NoteDepositBox12.Visible = true;
                NoteLabel12.Visible = true;
                NoteLabel12.Text = myDepositUnits.Bills[12].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox12.Visible = false;
                NoteLabel12.Visible = false;
            }

            // Bill 13?

            if (BillCounter > 0)
            {
                NoteDepositBox13.Visible = true;
                NoteLabel13.Visible = true;
                NoteLabel13.Text = myDepositUnits.Bills[13].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox13.Visible = false;
                NoteLabel13.Visible = false;
            }

            // Bill 14?

            if (BillCounter > 0)
            {
                NoteDepositBox14.Visible = true;
                NoteLabel14.Visible = true;
                NoteLabel14.Text = myDepositUnits.Bills[14].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox14.Visible = false;
                NoteLabel14.Visible = false;
            }

            // Bill 15?

            if (BillCounter > 0)
            {
                NoteDepositBox15.Visible = true;
                NoteLabel15.Visible = true;
                NoteLabel15.Text = myDepositUnits.Bills[15].ToString();
                BillCounter--;
            }
            else
            {
                NoteDepositBox15.Visible = false;
                NoteLabel15.Visible = false;
            }
        }

        private void PopulateDispenseCoinCurrencyValues()
        {
            int CoinCounter = myDispenseUnits.Coins.Length;

            // Coin 0?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo0.Visible = true;
                CoinDispenseLabel0.Visible = true;
                CoinDispenseLabel0.Text = myDispenseUnits.Coins[0].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo0.Visible = false;
                CoinDispenseLabel0.Visible = false;
            }

            // Coin 1?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo1.Visible = true;
                CoinDispenseLabel1.Visible = true;
                CoinDispenseLabel1.Text = myDispenseUnits.Coins[1].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo1.Visible = false;
                CoinDispenseLabel1.Visible = false;
            }

            // Coin 2?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo2.Visible = true;
                CoinDispenseLabel2.Visible = true;
                CoinDispenseLabel2.Text = myDispenseUnits.Coins[2].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo2.Visible = false;
                CoinDispenseLabel2.Visible = false;
            }

            // Coin 3?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo3.Visible = true;
                CoinDispenseLabel3.Visible = true;
                CoinDispenseLabel3.Text = myDispenseUnits.Coins[3].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo3.Visible = false;
                CoinDispenseLabel3.Visible = false;
            }

            // Coin 4?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo4.Visible = true;
                CoinDispenseLabel4.Visible = true;
                CoinDispenseLabel4.Text = myDispenseUnits.Coins[4].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo4.Visible = false;
                CoinDispenseLabel4.Visible = false;
            }

            // Coin 5?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo5.Visible = true;
                CoinDispenseLabel5.Visible = true;
                CoinDispenseLabel5.Text = myDispenseUnits.Coins[5].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo5.Visible = false;
                CoinDispenseLabel5.Visible = false;
            }

            // Coin 6?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo6.Visible = true;
                CoinDispenseLabel6.Visible = true;
                CoinDispenseLabel6.Text = myDispenseUnits.Coins[6].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo6.Visible = false;
                CoinDispenseLabel6.Visible = false;
            }

            // Coin 7?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo7.Visible = true;
                CoinDispenseLabel7.Visible = true;
                CoinDispenseLabel7.Text = myDispenseUnits.Coins[7].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo7.Visible = false;
                CoinDispenseLabel7.Visible = false;
            }

            // Coin 8?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo8.Visible = true;
                CoinDispenseLabel8.Visible = true;
                CoinDispenseLabel8.Text = myDispenseUnits.Coins[8].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo8.Visible = false;
                CoinDispenseLabel8.Visible = false;
            }

            // Coin 9?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo9.Visible = true;
                CoinDispenseLabel9.Visible = true;
                CoinDispenseLabel9.Text = myDispenseUnits.Coins[9].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo9.Visible = false;
                CoinDispenseLabel9.Visible = false;
            }

            // Coin 10?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo10.Visible = true;
                CoinDispenseLabel10.Visible = true;
                CoinDispenseLabel10.Text = myDispenseUnits.Coins[10].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo10.Visible = false;
                CoinDispenseLabel10.Visible = false;
            }

            // Coin 11?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo11.Visible = true;
                CoinDispenseLabel11.Visible = true;
                CoinDispenseLabel11.Text = myDispenseUnits.Coins[11].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo11.Visible = false;
                CoinDispenseLabel11.Visible = false;
            }

            // Coin 12?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo12.Visible = true;
                CoinDispenseLabel12.Visible = true;
                CoinDispenseLabel12.Text = myDispenseUnits.Coins[12].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo12.Visible = false;
                CoinDispenseLabel12.Visible = false;
            }

            // Coin 13?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo13.Visible = true;
                CoinDispenseLabel13.Visible = true;
                CoinDispenseLabel13.Text = myDispenseUnits.Coins[13].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo13.Visible = false;
                CoinDispenseLabel13.Visible = false;
            }

            // Coin 14?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo14.Visible = true;
                CoinDispenseLabel14.Visible = true;
                CoinDispenseLabel14.Text = myDispenseUnits.Coins[14].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo14.Visible = false;
                CoinDispenseLabel14.Visible = false;
            }

            // Coin 15?

            if (CoinCounter > 0)
            {
                CoinDispenseCombo15.Visible = true;
                CoinDispenseLabel15.Visible = true;
                CoinDispenseLabel15.Text = myDispenseUnits.Coins[15].ToString();
                CoinCounter--;
            }
            else
            {
                CoinDispenseCombo15.Visible = false;
                CoinDispenseLabel15.Visible = false;
            }
        }

        private void PopulateDispenseBillCurrencyValues()
        {
            int BillCounter = myDispenseUnits.Bills.Length;

            // Bill 0?

            if (BillCounter > 0)
            {
                NoteDispenseCombo0.Visible = true;
                NoteDispenseLabel0.Visible = true;
                NoteDispenseLabel0.Text = myDispenseUnits.Bills[0].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo0.Visible = false;
                NoteDispenseLabel0.Visible = false;
            }

            // Bill 1?

            if (BillCounter > 0)
            {
                NoteDispenseCombo1.Visible = true;
                NoteDispenseLabel1.Visible = true;
                NoteDispenseLabel1.Text = myDispenseUnits.Bills[1].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo1.Visible = false;
                NoteDispenseLabel1.Visible = false;
            }

            // Bill 2?

            if (BillCounter > 0)
            {
                NoteDispenseCombo2.Visible = true;
                NoteDispenseLabel2.Visible = true;
                NoteDispenseLabel2.Text = myDispenseUnits.Bills[2].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo2.Visible = false;
                NoteDispenseLabel2.Visible = false;
            }

            // Bill 3?

            if (BillCounter > 0)
            {
                NoteDispenseCombo3.Visible = true;
                NoteDispenseLabel3.Visible = true;
                NoteDispenseLabel3.Text = myDispenseUnits.Bills[3].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo3.Visible = false;
                NoteDispenseLabel3.Visible = false;
            }

            // Bill 4?

            if (BillCounter > 0)
            {
                NoteDispenseCombo4.Visible = true;
                NoteDispenseLabel4.Visible = true;
                NoteDispenseLabel4.Text = myDispenseUnits.Bills[4].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo4.Visible = false;
                NoteDispenseLabel4.Visible = false;
            }

            // Bill 5?

            if (BillCounter > 0)
            {
                NoteDispenseCombo5.Visible = true;
                NoteDispenseLabel5.Visible = true;
                NoteDispenseLabel5.Text = myDispenseUnits.Bills[5].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo5.Visible = false;
                NoteDispenseLabel5.Visible = false;
            }

            // Bill 6?

            if (BillCounter > 0)
            {
                NoteDispenseCombo6.Visible = true;
                NoteDispenseLabel6.Visible = true;
                NoteDispenseLabel6.Text = myDispenseUnits.Bills[6].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo6.Visible = false;
                NoteDispenseLabel6.Visible = false;
            }

            // Bill 7?

            if (BillCounter > 0)
            {
                NoteDispenseCombo7.Visible = true;
                NoteDispenseLabel7.Visible = true;
                NoteDispenseLabel7.Text = myDispenseUnits.Bills[7].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo7.Visible = false;
                NoteDispenseLabel7.Visible = false;
            }

            // Bill 8?

            if (BillCounter > 0)
            {
                NoteDispenseCombo8.Visible = true;
                NoteDispenseLabel8.Visible = true;
                NoteDispenseLabel8.Text = myDispenseUnits.Bills[8].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo8.Visible = false;
                NoteDispenseLabel8.Visible = false;
            }

            // Bill 9?

            if (BillCounter > 0)
            {
                NoteDispenseCombo9.Visible = true;
                NoteDispenseLabel9.Visible = true;
                NoteDispenseLabel9.Text = myDispenseUnits.Bills[9].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo9.Visible = false;
                NoteDispenseLabel9.Visible = false;
            }

            // Bill 10?

            if (BillCounter > 0)
            {
                NoteDispenseCombo10.Visible = true;
                NoteDispenseLabel10.Visible = true;
                NoteDispenseLabel10.Text = myDispenseUnits.Bills[10].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo10.Visible = false;
                NoteDispenseLabel10.Visible = false;
            }

            // Bill 11?

            if (BillCounter > 0)
            {
                NoteDispenseCombo11.Visible = true;
                NoteDispenseLabel11.Visible = true;
                NoteDispenseLabel11.Text = myDispenseUnits.Bills[11].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo11.Visible = false;
                NoteDispenseLabel11.Visible = false;
            }

            // Bill 12?

            if (BillCounter > 0)
            {
                NoteDispenseCombo12.Visible = true;
                NoteDispenseLabel12.Visible = true;
                NoteDispenseLabel12.Text = myDispenseUnits.Bills[12].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo12.Visible = false;
                NoteDispenseLabel12.Visible = false;
            }

            // Bill 13?

            if (BillCounter > 0)
            {
                NoteDispenseCombo13.Visible = true;
                NoteDispenseLabel13.Visible = true;
                NoteDispenseLabel13.Text = myDispenseUnits.Bills[13].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo13.Visible = false;
                NoteDispenseLabel13.Visible = false;
            }

            // Bill 14?

            if (BillCounter > 0)
            {
                NoteDispenseCombo14.Visible = true;
                NoteDispenseLabel14.Visible = true;
                NoteDispenseLabel14.Text = myDispenseUnits.Bills[14].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo14.Visible = false;
                NoteDispenseLabel14.Visible = false;
            }

            // Bill 15?

            if (BillCounter > 0)
            {
                NoteDispenseCombo15.Visible = true;
                NoteDispenseLabel15.Visible = true;
                NoteDispenseLabel15.Text = myDispenseUnits.Bills[15].ToString();
                BillCounter--;
            }
            else
            {
                NoteDispenseCombo15.Visible = false;
                NoteDispenseLabel15.Visible = false;
            }
        }

        private void UpdateDepositedCashTotals()
        {
            DepositAmountTextBox.Text = myChanger.DepositAmount.ToString();

            CashCount[] LatestCash = myChanger.DepositCounts;

            int CoinOrNoteCounter = LatestCash.Length ;

            for (int i = 0 ; i < CoinOrNoteCounter ; i++)
            {
                if (LatestCash[i].Type == CashCountType.Bill)
                {
                    // Then we have a bill count to update

                    int j;

                    int    BillValue = LatestCash[i].NominalValue;
                    string BillCount = LatestCash[i].Count.ToString();

                    for (j = 0; j < myDepositUnits.Bills.Length; j++)
                    {
                        if (BillValue == myDepositUnits.Bills[j])
                        {
                            // Then we have found the correct bill!
                            
                            break;
                        }
                    }

                    if (j < myDepositUnits.Bills.Length)
                    {
                        // Then we did find a matching bill!

                        switch (j)
                        {
                            case 0:
                                NoteDepositBox0.Text = BillCount;
                                break;
                            case 1:
                                NoteDepositBox1.Text = BillCount;
                                break;
                            case 2:
                                NoteDepositBox2.Text = BillCount;
                                break;
                            case 3:
                                NoteDepositBox3.Text = BillCount;
                                break;
                            case 4:
                                NoteDepositBox4.Text = BillCount;
                                break;
                            case 5:
                                NoteDepositBox5.Text = BillCount;
                                break;
                            case 6:
                                NoteDepositBox6.Text = BillCount;
                                break;
                            case 7:
                                NoteDepositBox7.Text = BillCount;
                                break;
                            case 8:
                                NoteDepositBox8.Text = BillCount;
                                break;
                            case 9:
                                NoteDepositBox9.Text = BillCount;
                                break;
                            case 10:
                                NoteDepositBox10.Text = BillCount;
                                break;
                            case 11:
                                NoteDepositBox11.Text = BillCount;
                                break;
                            case 12:
                                NoteDepositBox12.Text = BillCount;
                                break;
                            case 13:
                                NoteDepositBox13.Text = BillCount;
                                break;
                            case 14:
                                NoteDepositBox14.Text = BillCount;
                                break;
                            case 15:
                                NoteDepositBox15.Text = BillCount;
                                break;
                        }
                    }
                }
                else
                {
                    // Then we have a coin count to update

                    int j;

                    int CoinValue = LatestCash[i].NominalValue;
                    string CoinCount = LatestCash[i].Count.ToString();

                    for (j = 0; j < myDepositUnits.Coins.Length; j++)
                    {
                        if (CoinValue == myDepositUnits.Coins[j])
                        {
                            // Then we have found the correct bill!

                            break;
                        }
                    }

                    if (j < myDepositUnits.Coins.Length)
                    {
                        // Then we did find a matching bill!

                        switch (j)
                        {
                            case 0:
                                CoinDepositBox0.Text = CoinCount;
                                break;
                            case 1:
                                CoinDepositBox1.Text = CoinCount;
                                break;
                            case 2:
                                CoinDepositBox2.Text = CoinCount;
                                break;
                            case 3:
                                CoinDepositBox3.Text = CoinCount;
                                break;
                            case 4:
                                CoinDepositBox4.Text = CoinCount;
                                break;
                            case 5:
                                CoinDepositBox5.Text = CoinCount;
                                break;
                            case 6:
                                CoinDepositBox6.Text = CoinCount;
                                break;
                            case 7:
                                CoinDepositBox7.Text = CoinCount;
                                break;
                            case 8:
                                CoinDepositBox8.Text = CoinCount;
                                break;
                            case 9:
                                CoinDepositBox9.Text = CoinCount;
                                break;
                            case 10:
                                CoinDepositBox10.Text = CoinCount;
                                break;
                            case 11:
                                CoinDepositBox11.Text = CoinCount;
                                break;
                            case 12:
                                CoinDepositBox12.Text = CoinCount;
                                break;
                            case 13:
                                CoinDepositBox13.Text = CoinCount;
                                break;
                            case 14:
                                CoinDepositBox14.Text = CoinCount;
                                break;
                            case 15:
                                CoinDepositBox15.Text = CoinCount;
                                break;
                        }
                    }
                }
            }
        }

        private int  GetCoinPayCount(int CoinNumber)
        {
            int CoinsToPay;

            switch (CoinNumber)
            {
                case 0:
                    CoinsToPay = CoinDispenseCombo0.SelectedIndex;
                    break;
                case 1:
                    CoinsToPay = CoinDispenseCombo1.SelectedIndex;
                    break;
                case 2:
                    CoinsToPay = CoinDispenseCombo2.SelectedIndex;
                    break;
                case 3:
                    CoinsToPay = CoinDispenseCombo3.SelectedIndex;
                    break;
                case 4:
                    CoinsToPay = CoinDispenseCombo4.SelectedIndex;
                    break;
                case 5:
                    CoinsToPay = CoinDispenseCombo5.SelectedIndex;
                    break;
                case 6:
                    CoinsToPay = CoinDispenseCombo6.SelectedIndex;
                    break;
                case 7:
                    CoinsToPay = CoinDispenseCombo7.SelectedIndex;
                    break;
                case 8:
                    CoinsToPay = CoinDispenseCombo8.SelectedIndex;
                    break;
                case 9:
                    CoinsToPay = CoinDispenseCombo9.SelectedIndex;
                    break;
                case 10:
                    CoinsToPay = CoinDispenseCombo10.SelectedIndex;
                    break;
                case 11:
                    CoinsToPay = CoinDispenseCombo11.SelectedIndex;
                    break;
                case 12:
                    CoinsToPay = CoinDispenseCombo12.SelectedIndex;
                    break;
                case 13:
                    CoinsToPay = CoinDispenseCombo13.SelectedIndex;
                    break;
                case 14:
                    CoinsToPay = CoinDispenseCombo14.SelectedIndex;
                    break;
                case 15:
                    CoinsToPay = CoinDispenseCombo15.SelectedIndex;
                    break;
                default:
                    CoinsToPay = 0;
                    break;
            }

            return CoinsToPay;
        }

        private int  GetNotePayCount(int NoteNumber)
        {
            int NotesToPay;

            switch (NoteNumber)
            {
                case 0:
                    NotesToPay = NoteDispenseCombo0.SelectedIndex;
                    break;
                case 1:
                    NotesToPay = NoteDispenseCombo1.SelectedIndex;
                    break;
                case 2:
                    NotesToPay = NoteDispenseCombo2.SelectedIndex;
                    break;
                case 3:
                    NotesToPay = NoteDispenseCombo3.SelectedIndex;
                    break;
                case 4:
                    NotesToPay = NoteDispenseCombo4.SelectedIndex;
                    break;
                case 5:
                    NotesToPay = NoteDispenseCombo5.SelectedIndex;
                    break;
                case 6:
                    NotesToPay = NoteDispenseCombo6.SelectedIndex;
                    break;
                case 7:
                    NotesToPay = NoteDispenseCombo7.SelectedIndex;
                    break;
                case 8:
                    NotesToPay = NoteDispenseCombo8.SelectedIndex;
                    break;
                case 9:
                    NotesToPay = NoteDispenseCombo9.SelectedIndex;
                    break;
                case 10:
                    NotesToPay = NoteDispenseCombo10.SelectedIndex;
                    break;
                case 11:
                    NotesToPay = NoteDispenseCombo11.SelectedIndex;
                    break;
                case 12:
                    NotesToPay = NoteDispenseCombo12.SelectedIndex;
                    break;
                case 13:
                    NotesToPay = NoteDispenseCombo13.SelectedIndex;
                    break;
                case 14:
                    NotesToPay = NoteDispenseCombo14.SelectedIndex;
                    break;
                case 15:
                    NotesToPay = NoteDispenseCombo15.SelectedIndex;
                    break;
                default:
                    NotesToPay = 0;
                    break;
            }

            return NotesToPay;
        }

        #endregion Support Functions

    }
}
